@@ -34,8 +34,13 @@
    if (!isSVG)
       x <- png::readPNG(fileout,native=FALSE,info=TRUE)
    dimx <- dim(x)
-   b <- .Cursa("internalMargin",x=as.numeric(x),dim=as.integer(dimx)
-          ,indr=integer(dimx[1]),indc=integer(dimx[2]),NAOK=TRUE)
+   isBlack <- isTRUE(getOption("ursaPngBackground") %in% (c("black","#000000")))
+   if (isBlack)
+      b <- .Cursa("internalMargin",x=1-as.numeric(x),dim=as.integer(dimx)
+             ,indr=integer(dimx[1]),indc=integer(dimx[2]),NAOK=TRUE)
+   else
+      b <- .Cursa("internalMargin",x=as.numeric(x),dim=as.integer(dimx)
+             ,indr=integer(dimx[1]),indc=integer(dimx[2]),NAOK=TRUE)
    indentc <- rep(which(b$indc==1)[1],frame)
    d <- diff(b$indc)
    s1 <- which(d==-1)+1L
